Welcome to cnewtonprop's documentation!
=======================================

.. image:: https://img.shields.io/badge/github-qucontrol/cnewtonprop-blue.svg
   :alt: Source code on Github
   :target: https://github.com/qucontrol/cnewtonprop
.. image:: https://img.shields.io/pypi/v/cnewtonprop.svg
   :alt: cnewtonprop on the Python Package Index
   :target: https://pypi.python.org/pypi/cnewtonprop

.. image:: https://img.shields.io/travis/qucontrol/cnewtonprop.svg
   :alt: Travis Continuous Integration
   :target: https://travis-ci.org/qucontrol/cnewtonprop
.. image:: https://img.shields.io/badge/appveyor-no%20id-red.svg
   :alt: AppVeyor Continuous Integration
   :target: https://ci.appveyor.com/project/qucontrol/cnewtonprop
.. image:: https://img.shields.io/coveralls/github/qucontrol/cnewtonprop/master.svg
   :alt: Coveralls
   :target: https://coveralls.io/github/qucontrol/cnewtonprop?branch=master
.. image:: https://readthedocs.org/projects/cnewtonprop/badge/?version=latest
   :alt: Documentation Status
   :target: https://cnewtonprop.readthedocs.io/en/latest/?badge=latest
.. image:: https://img.shields.io/badge/License-BSD-green.svg
   :alt: BSD License
   :target: https://opensource.org/licenses/BSD-3-Clause

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   contributing
   authors
   history
   tutorial.ipynb


API
===

.. toctree::
   :maxdepth: 1

   API of the cnewtonprop package <API/cnewtonprop>

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
